# Welcome to `ez_zarr`

## Goals
The aim of `ez_zarr` is to provide easy, high-level access
to OME-Zarr filesets (high content screening microscopy data, stored
according to the [NGFF](https://ngff.openmicroscopy.org/latest/)
specifications in OME-Zarr with additional metadata fields, for
example the ones generated by the [Fractal](https://fractal-analytics-platform.github.io/fractal-tasks-core/) platform).

The goal is that users can write simple scripts working with plates,
wells and fields of view, without having to understand how these
are represented within an OME-Zarr fileset.

## Example
You can use `ez_zarr` from the command line to get information about an OME-Zarr fileset:
```
ez_zarr tests/example_data/plate_ones.zarr
```

or from within python to get access to all its functionality:
```
# import module
from ez_zarr import hcs_wrappers

# create `plate_3d` object representing an OME-Zarr fileset
plate_3d = hcs_wrappers.FractalZarr('tests/example_data/plate_ones.zarr')

# print fileset summary
plate_3d
# FractalZarr plate_ones.zarr
#   path: tests/example_data/plate_ones.zarr
#   n_wells: 1
#   n_channels: 2 (some-label-1, some-label-2)
#   n_pyramid_levels: 3
#   pyramid_zyx_scalefactor: {'0': array([1. 2. 2.])}
#   full_resolution_zyx_spacing: [1.0, 0.1625, 0.1625]
#   segmentations: 
#   tables (measurements): FOV_ROI_table
```

A more extensive example is available from [here](https://fmicompbio.github.io/ez_zarr/getting_started_hcs_wrappers/), also available as an [ipynb notebook](https://fmicompbio.github.io/ez_zarr/getting_started_hcs_wrappers.ipynb).

## Install

`ez_zarr` is hosted on GitHub at [github.com/fmicompbio/ez_zarr](https://github.com/fmicompbio/ez_zarr) and the documentation can be found at [fmicompbio.github.io/ez_zarr](https://fmicompbio.github.io/ez_zarr/).

The release version of `ez_zarr` can be installed using:
```
pip install ez-zarr
```

The current (development) version of `ez_zarr` can be installed from github.com using:
```
pip install git+ssh://git@github.com/fmicompbio/ez_zarr.git
```

## Software status
[![unit-tests](https://github.com/fmicompbio/ez_zarr/actions/workflows/test_and_deploy.yaml/badge.svg)](https://github.com/fmicompbio/ez_zarr/actions/workflows/test_and_deploy.yaml)
[![codecov](https://codecov.io/gh/fmicompbio/ez_zarr/graph/badge.svg?token=GEBLX8ENJ1)](https://codecov.io/gh/fmicompbio/ez_zarr)

## Contributors and License
`ez_zarr` is released under the MIT License, and the copyright
is with the Friedrich Miescher Insitute for Biomedical Research
(see [LICENSE](https://github.com/fmicompbio/ez_zarr/blob/main/LICENSE)).

`ez_zarr` is being developed at the Friedrich Miescher Institute for
Biomedical Research by [@silvbarb](https://github.com/silvbarb) and [@mbstadler](https://github.com/mbstadler).